@@ -5,7 +5,7 @@ from abc import ABC as _ABC
 
 import numpy as _np
 import torchvision.transforms as _tmf
-from easytorch.data import DiskCache as _DiskCache, ETDataset as _ETDataset
+from easytorch.data import ETDataset as _ETDataset
 import easytorch.vision.imageutils as _imgutils
 
 sep = _os.sep
@@ -16,7 +16,6 @@ class BaseImageDataset(_ETDataset, _ABC):
         super().__init__(**kw)
         self.transforms = self.get_transforms()
         self.pil_to_tensor = _tmf.Compose([_tmf.ToPILImage(), _tmf.ToTensor()])
-        self.diskcache = _DiskCache(self.args['log_dir'] + _os.sep + "_cache")
 
     def get_transforms(self):
         return _tmf.Compose([_tmf.ToPILImage(), _tmf.ToTensor()])
@@ -69,8 +68,7 @@ class PatchedImgDataset(BaseImageDataset, _ABC):
         dt = self.dataspecs[dataset_name]
         obj = self.load_img(dt, file)
 
-        cache_key = f"{dataset_name}_{file}"
-        self.diskcache.add(cache_key, obj)
+        cache_key = self.diskcache.add(f"{dataset_name}_{file}", obj)
         for corners in _imgutils.get_chunk_indexes(
                 obj.array.shape[:2],
                 dt['patch_shape'],
@@ -261,8 +259,7 @@ class FullImgDataset(BaseImageDataset):
             self.labels = self._load_labels(dspec)
 
         img_obj = self.load_img(dspec, file)
-        cache_key = f"{dataset_name}_{file}"
-        self.diskcache.add(cache_key, img_obj)
+        cache_key = self.diskcache.add(f"{dataset_name}_{file}", img_obj)
         self.indices.append([dataset_name, file, self._get_label(file), cache_key])
 
     def __getitem__(self, index):
